@@ -11,6 +11,9 @@ def saleOut():
 
     data = db.getCode(app3)
 
+    ut.demo()
+    mt.demo()
+
     if data:
 
         res = ut.classification_process(app3, data)
